@@ -383,7 +383,7 @@ class DataFrame(dict):
         other_by_id = {other_ids[i]: i for i in range(other.nrow)}
         self_ids = zip(*[self[x] for x in by1])
         src = map(lambda x: other_by_id.get(x, -1), self_ids)
-        src = np.fromiter(src, np.int, count=self.nrow)
+        src = np.fromiter(src, int, count=self.nrow)
         found = np.where(src > -1)
         return found, src
 
@@ -716,7 +716,7 @@ class DataFrame(dict):
                 if dir not in [1, -1]:
                     raise ValueError("dir should be 1 or -1")
                 column = self[colname]
-                if dir < 0 and not (column.is_boolean or column.is_number):
+                if dir < 0 and not (column.is_boolean() or column.is_number()):
                     # Use rank for non-numeric types so that we can sort descending.
                     column = column.rank()
                 yield column if dir >= 0 else -column
