@@ -24,11 +24,11 @@ import dataiter
 import itertools
 import math
 import numpy as np
-import os
 import shutil
 import string
 
 from dataiter import deco
+from pathlib import Path
 
 
 def count_digits(value):
@@ -62,9 +62,7 @@ def length(value):
     return 1 if np.isscalar(value) else len(value)
 
 def makedirs_for_file(fname):
-    fname = os.path.abspath(fname)
-    directory = os.path.dirname(fname)
-    return os.makedirs(directory, exist_ok=True)
+    return Path(fname).parent.mkdir(parents=True, exist_ok=True)
 
 @deco.listify
 def pad(strings, align="right"):
@@ -82,7 +80,9 @@ def unique_keys(keys):
     return list(dict.fromkeys(keys))
 
 def unique_types(seq):
-    return set(x.__class__ for x in seq if x not in [None, np.nan])
+    return set(x.__class__ for x in seq if
+               x is not None and
+               not (isinstance(x, float) and np.isnan(x)))
 
 def yield_colnames():
     # Like Excel: a, b, c, ..., aa, bb, cc, ...
